Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mpu6050_simpletest.py
    :caption: examples/mpu6050_simpletest.py
    :linenos:

Plotter Example
---------------

See the effects of changing the gyroscope and accelerometer range
by viewing the data in a serial plotter

.. literalinclude:: ../examples/mpu6050_plotter_example.py
    :caption: examples/mpu6050_plotter_example.py
    :linenos:

Sleep Example
---------------

Observe how the cycle and sleep modes effect measurements 
by viewing the data in a serial plotter

.. literalinclude:: ../examples/mpu6050_sleep_example.py
    :caption: examples/mpu6050_sleep_example.py
    :linenos:
